##  Running KarmaJS's AngularJS example test/e2e/angular-scenario (on Chrome)

To learn and get an idea of how [Karma](http://karma-runner.github.io/0.8/index.html) (the _'Spectacular Test Runner for JavaScript'_) works, and how it can be used to create browser automations tests, here are the steps I took to get the [test/e2e/angular-scenario](https://github.com/karma-runner/karma/tree/master/test/e2e/angular-scenario) example to work.

It all started with a clone of: [git@github.com:karma-runner/karma.git](mailto:git@github.com:karma-runner/karma.git)  

![](images/image_thumb-12.png)

With this KarmaJS test example (see below), being the one that we are going to use:

![](images/image_thumb-13.png)

I then opened an nodejs command prompt and navigated to the folder shown above:

![](images/image_thumb-14.png)

... used **_node server.js_** to start a local webserver

![](images/image_thumb-15.png)

... on port 8000:

![](images/image_thumb-16.png)

The test case we are using (on KarmaJS's **_test/e2e/angular-scenario_**) is a simple AngularJS example, which just consumes the angular-min.js file model attribute:

![](images/image_thumb_25255B11_25255D.png)

... and uses angular to populate the **_{{yourName}}_** value dynamically (wired to the input field via the **_ng-model="yourName"_**)

![](images/image_thumb_25255B10_25255D1.png)

Next we are going to run this [Jasmine](http://pivotal.github.io/jasmine/) test using KarmaJS

![](images/image_thumb_25255B13_25255D.png)

... which _should_ work with just: **karma start karma.conf.js**  

![](images/image_thumb_25255B12_25255D.png)

... but it didn't

There is a module dependency missing, which in this case can be resolved by running this command from the root of the karma repository:

![](images/image_thumb_25255B14_25255D.png)

**Note:** the issue above was caused by the fact that I had an the official released version of karma installed globally which is the one that was running when I tried it on the 'test/e2e/angular-scenario' folder'

And now (based on an option from the karma.conf.js) a Chrome window opens up:

![](images/running-karma-5.png)

Clicking on the **_Debug_** button:

![](images/image_thumb_25255B18_25255D1.png)

... we can more details on the test that failed:

![](images/image_thumb_25255B19_25255D.png)

In this case the problem is that the 'proxy mapping' that karma does is not correct

If we look at the karma.config.js file

![](images/image_thumb_25255B20_25255D1.png)

.... and the unit test **_brower().navigateTo_** command

![](images/running-karma-6.png)

... we can see that karma will try to open **_/index.html_** from _**http://localhost:8000/test/e2e/angular-scenario/index.html**_

That is not going to work since the page we want it is on **http://localhost:8000/index.html** (which happened because we started **_node server.js_** on the **.../test/e2e/angular-scenario** folder)

![](images/running-karma-8.png)

One way to solved this, is to change the 'proxies' mapping to **_'/' : 'http://localhost:8000/'_**  

![](images/running-karma-7.png)

... and after stopping and starting the karma server:

![](images/image_thumb_25255B24_25255D.png)

all tests pass :)

![](images/running-karma-1.png)

**Changing and executing tests in real time**  

What is really cool with this set-up is that (as long as the karma process is running), because the **autoWatch** value (in _**karma.config.js**_) was set to true, if I make a change to the test file:

![](images/image_thumb_25255B26_25255D.png)

... the karma runner will detect the changes and rerun the tests (note that there are 2 tests executed now)

![](images/running-karma-2.png)

This 2nd test shows an interesting behaviors since it will make the test wait for 15 seconds (with the browser window opened):

![](images/image_thumb_25255B28_25255D.png)

Note how the time execution time for the 2nd test was ~15 secs

![](images/image_thumb_25255B29_25255D.png)

And if we modify the 2nd test to:

![](images/running-karma-3.png)

... the execution test UI will look like this (note that the execution was triggered when I saved the test file :)

![](images/image_thumb_25255B30_25255D.png)

**NOTE 1:** to solve the ENOENT error shown the first screenshot of localhost:8000, we need to add a favicon.ico file to the **lib/nodeserver** folder

![](images/running-karma-4.png)

... and now the error doesn't happen anymore

![](images/image_thumb_25255B5_25255D1.png)

**Note 2:** when trying to run Karma for the first time, I had a prob with grunt where it was failing with an **_Error: spawn ENOENT_**:

![](images/image_thumb_25255B33_25255D.png)

... this was resolved by installed the 32bit version of nodeJS and running **_npm install_** on the karma folder (after cloning it)

![](images/image_thumb_25255B32_25255D.png)
